@@ -112,9 +112,7 @@ class _relu_squared(autograd.Function):
     @classmethod
     def backward(self, ctx, dy):
         x, w, o = ctx.saved_tensors
-        zeros = torch.zeros_like(dy)
-        c = torch.sqrt(o)
-        dy = torch.where(c > 0, dy * c * 2, zeros)
+        dy = torch.sqrt(o) * 2 * dy
         dx = dy @ w.t()
         dw = x.transpose(-1, -2) @ dy
         return dx, dw
